@@ -7,7 +7,7 @@
 #' @param molar logical Flag indicating whether output should be in moles or
 #'   numbers
 #'
-#' @return A numeric array of multipliers
+#' @return A numeric vector of multipliers
 #'
 #' @export
 #' @examples
@@ -18,9 +18,9 @@
 #'
 e2quantum_multipliers <- function(w.length, molar = FALSE){
   # E = hc / w.length energy of one photon
-  # coverting (energy) irradiance (I) to photon irradiance (Q): I / E = Q
-  h = 6.626e-34 # Plank's contsant (Js)
-  c = 2.998e8 # speed of light in vaccum (m/s), so we convert m/s to nm/s
+  # converting (energy) irradiance (I) to photon irradiance (Q): I / E = Q
+  h = 6.626e-34 # Plank's constant (Js)
+  c = 2.998e8 # speed of light in vacuum (m/s), so we convert m/s to nm/s
   Na = 6.02214129e23 # Avogadro's number, photons per mol
 
   hc = h * c * 1e9
