@@ -3,18 +3,19 @@
 #' Function to calculate the mean, total, or other summary of absorbance for
 #' spectral data stored in a \code{filter_spct} or in an \code{object_spct}.
 #'
-#' @param spct an R object
+#' @param spct an R object.
 #' @param w.band waveband or list of waveband objects or a numeric vector of
 #'   length two. The waveband(s) determine the region(s) of the spectrum that
 #'   are summarized. If a numeric range is supplied a waveband object is
 #'   constructed on the fly from it.
 #' @param quantity character string One of "average" or "mean", "total",
-#'   "contribution", "contribution.pc", "relative" or "relative.pc"
+#'   "contribution", "contribution.pc", "relative" or "relative.pc".
 #' @param wb.trim logical Flag indicating if wavebands crossing spectral data
-#'   boundaries are trimmed or ignored
-#' @param use.hinges logical Flag indicating whether to use hinges to reduce
-#'   interpolation errors
-#' @param ... other arguments (possibly ignored)
+#'   boundaries are trimmed or ignored.
+#' @param use.hinges logical Flag indicating whether to insert "hinges" into the
+#'   spectral data before integration so as to reduce interpolation errors at
+#'   the boundaries of the wavebands.
+#' @param ... other arguments (possibly used by derived methods).
 #'
 #' @return A named \code{numeric} vector in the case of methods for individual
 #'   spectra, with one value for each \code{waveband} passed to parameter
@@ -133,7 +134,7 @@ absorbance_spct <-
     if (is.waveband(w.band)) {
       # if the argument is a single w.band, we enclose it in a list
       # so that the for loop works as expected.This is a bit of a
-      # cludge but let's us avoid treating it as a special case
+      # kludge but let's us avoid treating it as a special case
       w.band <- list(w.band)
     }
     w.band <- trim_waveband(w.band=w.band, range=spct, trim=wb.trim)
@@ -254,6 +255,13 @@ absorbance.filter_mspct <-
 # object_mspct methods -----------------------------------------------
 
 #' @describeIn absorbance Calculates absorbance from a \code{object_mspct}
+#' @param .parallel	if TRUE, apply function in parallel, using parallel backend
+#'   provided by foreach
+#' @param .paropts a list of additional options passed into the foreach function
+#'   when parallel computation is enabled. This is important if (for example)
+#'   your code relies on external data or packages: use the .export and
+#'   .packages arguments to supply them so that all cluster nodes have the
+#'   correct environment set up for computing.
 #'
 #' @export
 #'
@@ -264,7 +272,9 @@ absorbance.object_mspct <-
            use.hinges=getOption("photobiology.use.hinges", default = NULL),
            ...,
            attr2tb = NULL,
-           idx = !is.null(names(spct))) {
+           idx = !is.null(names(spct)),
+           .parallel = FALSE,
+           .paropts = NULL) {
     z <-
       msdply(
         mspct = spct,
@@ -274,7 +284,9 @@ absorbance.object_mspct <-
         wb.trim = wb.trim,
         use.hinges = use.hinges,
         col.names = names(w.band),
-        idx = idx
+        idx = idx,
+        .parallel = .parallel,
+        .paropts = .paropts
       )
     add_attr2tb(tb = z,
                 mspct = spct,
