@@ -2,18 +2,19 @@
 #'
 #' Summary transmittance for supplied wavebands from filter or object spectrum.
 #'
-#' @param spct an R object
+#' @param spct an R object.
 #' @param w.band waveband or list of waveband objects or a numeric vector of
 #'   length two. The waveband(s) determine the region(s) of the spectrum that
 #'   are summarized. If a numeric range is supplied a waveband object is
 #'   constructed on the fly from it.
 #' @param quantity character string One of "total", "average" or "mean",
-#'   "contribution", "contribution.pc", "relative" or "relative.pc"
+#'   "contribution", "contribution.pc", "relative" or "relative.pc".
 #' @param wb.trim logical Flag indicating if wavebands crossing spectral data boundaries
-#'   are trimmed or ignored
-#' @param use.hinges logical Flag indicating whether to use hinges to reduce
-#'   interpolation errors
-#' @param ... other arguments
+#'   are trimmed or ignored.
+#' @param use.hinges logical Flag indicating whether to insert "hinges" into the
+#'   spectral data before integration so as to reduce interpolation errors at
+#'   the boundaries of the wavebands.
+#' @param ... ignored (possibly used by derived methods).
 #'
 #' @return A named \code{numeric} vector in the case of methods for individual
 #'   spectra, with one value for each \code{waveband} passed to parameter
@@ -35,7 +36,7 @@
 #' transmittance(polyester.spct, waveband(c(400, 700)))
 #'
 #' @note The \code{use.hinges} parameter controls speed optimization. The
-#'   defaults should be suitable in mosts cases. Only the range of wavelengths
+#'   defaults should be suitable in most cases. Only the range of wavelengths
 #'   in the wavebands is used and all BSWFs are ignored.
 #'
 #' @export transmittance
@@ -84,26 +85,26 @@ transmittance.object_spct <-
 
 #' Calculate transmittance from spectral transmittance.
 #'
-#' This function returns the mean transmittance for a given waveband of a
-#' transmittance spectrum.
+#' Mean transmittance for one or more wavebands of a filter or object spectrum.
 #'
-#' @param spct an object of class "generic_spct"
+#' @param spct an object of class "generic_spct".
 #' @param w.band waveband or list of waveband objects or a numeric vector of
 #'   length two. The waveband(s) determine the region(s) of the spectrum that
 #'   are summarized. If a numeric range is supplied a waveband object is
 #'   constructed on the fly from it.
 #' @param quantity character string One of "total", "average" or "mean",
-#'   "contribution", "contribution.pc", "relative" or "relative.pc"
+#'   "contribution", "contribution.pc", "relative" or "relative.pc".
 #' @param wb.trim logical Flag indicating if wavebands crossing spectral data boundaries
-#'   are trimmed or ignored
-#' @param use.hinges logical Flag indicating whether to use hinges to reduce
-#'   interpolation errors
+#'   are trimmed or ignored.
+#' @param use.hinges logical Flag indicating whether to insert "hinges" into the
+#'   spectral data before integration so as to reduce interpolation errors at
+#'   the boundaries of the wavebands.
 #'
 #' @return a single numeric value
 #' @keywords internal
 #'
 #' @note The last parameter controls speed optimization. The defaults should be
-#'   suitable in mosts cases. Only the range of wavelengths in the wavebands is
+#'   suitable in most cases. Only the range of wavelengths in the wavebands is
 #'   used and all BSWFs are ignored.
 
 transmittance_spct <-
@@ -137,7 +138,7 @@ transmittance_spct <-
     if (is.waveband(w.band)) {
       # if the argument is a single w.band, we enclose it in a list
       # so that the for loop works as expected.This is a bit of a
-      # cludge but let's us avoid treating it as a special case
+      # kludge but let's us avoid treating it as a special case
       w.band <- list(w.band)
     }
     w.band <- trim_waveband(w.band = w.band, range = spct, trim = wb.trim)
@@ -261,6 +262,13 @@ transmittance.filter_mspct <-
 # object_mspct methods -----------------------------------------------
 
 #' @describeIn transmittance Calculates transmittance from a \code{object_mspct}
+#' @param .parallel	if TRUE, apply function in parallel, using parallel backend
+#'   provided by foreach
+#' @param .paropts a list of additional options passed into the foreach function
+#'   when parallel computation is enabled. This is important if (for example)
+#'   your code relies on external data or packages: use the .export and
+#'   .packages arguments to supply them so that all cluster nodes have the
+#'   correct environment set up for computing.
 #'
 #' @export
 #'
@@ -271,7 +279,9 @@ transmittance.object_mspct <-
            use.hinges = getOption("photobiology.use.hinges", default = NULL),
            ...,
            attr2tb = NULL,
-           idx = !is.null(names(spct)) ) {
+           idx = !is.null(names(spct)),
+           .parallel = FALSE,
+           .paropts = NULL) {
     z <-
       msdply(
         mspct = spct,
@@ -281,11 +291,11 @@ transmittance.object_mspct <-
         wb.trim = wb.trim,
         use.hinges = use.hinges,
         idx = idx,
-        col.names = names(w.band)
+        col.names = names(w.band),
+        .parallel = .parallel,
+        .paropts = .paropts
       )
     add_attr2tb(tb = z,
                 mspct = spct,
                 col.names = attr2tb)
   }
-
-
