@@ -310,166 +310,11 @@ spread.generic_mspct <- function(x, ..., idx = !is.null(names(x))) {
   msdply(mspct = x, .fun = spread, ..., idx = idx)
 }
 
-# color -------------------------------------------------------------------
-
-#' Color of an object
-#'
-#' A function that returns the equivalent RGB color of an object such as a
-#' spectrum or wavelength.
-#'
-#' @param x an R object
-#' @param ... not used in current version
-#' @export color
-#'
-#' @examples
-#' wavelengths <- c(300, 420, 500, 600, NA) # nanometres
-#' color(wavelengths)
-#' color(waveband(c(300,400)))
-#' color(list(blue = waveband(c(400,480)), red = waveband(c(600,700))))
-#' color(numeric())
-#' color(NA_real_)
-#'
-#' color(sun.spct)
-#'
-#'
-color <- function(x, ...) UseMethod("color")
-
-#' @describeIn color Default method (returns always "black").
-#'
-#' @export
-#'
-color.default <- function(x, ...) {
-  if (length(x) == 0) {
-    return(character())
-  }
-  ifelse(is.na(x),
-         NA_character_,
-         rep("#000000", length(x)))
-}
-
-#' @describeIn color Method that returns Color definitions corresponding to
-#'   numeric values representing a wavelengths in nm.
-#'
-#' @param type character telling whether "CMF", "CC", or "both" should be returned.
-#'
-#' @export
-#'
-color.numeric <- function(x, type="CMF", ...) {
-  if (length(x) == 0) {
-    return(character())
-  }
-  color.out <- rep(NA_character_, length(x))
-  if (!all(is.na(x))) {
-    if (type == "CMF") {
-      color.out[!is.na(x)] <-
-        w_length2rgb(x[!is.na(x)], sens = photobiology::ciexyzCMF2.spct, color.name = NULL)
-    } else if (type == "CC") {
-      color.out[!is.na(x)] <-
-        w_length2rgb(x[!is.na(x)], sens = photobiology::ciexyzCC2.spct, color.name = NULL)
-    } else {
-      warning("Color 'type' = ", type, " not implemented for 'numeric'.")
-    }
-  }
-  if (!is.null(names(x))) {
-    names(color.out) <- paste(names(x), type, sep = ".")
-  }
-  color.out
-}
-
-#' @describeIn color Method that returns Color of elements in a list.
-#'
-#' @param short.names logical indicating whether to use short or long names for
-#'   wavebands
-#'
-#' @note When \code{x} is a list but not a waveband, if a method  \code{color}
-#'   is not available for the class of each element of the list, then
-#'   \code{color.default} will be called.
-#' @export
-#'
-color.list <- function(x, short.names=TRUE, type="CMF", ...) {
-  color.out <- character(0)
-  for (xi in x) {
-    color.out <- c(color.out, color(xi, short.names = short.names, type = type, ...))
-  }
-  if (!is.null(names(x))) {
-    names(color.out) <- paste(names(x), type, sep = ".")
-  }
-  return(color.out)
-}
-
-#' @describeIn color Color at midpoint of a \code{\link{waveband}} object.
-#'
-#' @export
-#'
-color.waveband <- function(x, short.names = TRUE, type = "CMF", ...) {
-  idx <- ifelse(!short.names, "name", "label")
-  name <- labels(x)[[idx]]
-  if (type == "both") {
-    color <- list(CMF = w_length_range2rgb(range(x),
-                                           sens = photobiology::ciexyzCMF2.spct,
-                                           color.name = paste(name, "CMF", sep = ".")),
-                  CC  = w_length_range2rgb(range(x),
-                                           sens = photobiology::ciexyzCC2.spct,
-                                           color.name = paste(name, "CC", sep = ".")))
-  } else if (type == "CMF") {
-    color <- w_length_range2rgb(range(x),
-                                sens = photobiology::ciexyzCMF2.spct,
-                                color.name = paste(name, "CMF", sep = "."))
-  } else if (type == "CC") {
-    color <- w_length_range2rgb(range(x),
-                                sens = photobiology::ciexyzCC2.spct,
-                                color.name = paste(name, "CC", sep = "."))
-  } else {
-    color <- NA
-  }
-  return(color)
-}
-
-#' @describeIn color
-#'
-#' @export
-#'
-color.source_spct <- function(x, type = "CMF", ...) {
-  if (length(x) == 0) {
-    return(character())
-  }
-  x.name <- "source"
-  q2e(x, byref = TRUE)
-  if (type %in% c("CMF", "CC")) {
-    s_e_irrad2rgb(x[["w.length"]], x[["s.e.irrad"]],
-                  sens = photobiology::ciexyzCMF2.spct, color.name = paste(x.name, type))
-  } else if (type == "both") {
-    c(s_e_irrad2rgb(x[["w.length"]], x[["s.e.irrad"]],
-                    sens = photobiology::ciexyzCMF2.spct, color.name = paste(x.name, "CMF")),
-      s_e_irrad2rgb(x[["w.length"]], x[["s.e.irrad"]],
-                    sens = photobiology::ciexyzCC2.spct, color.name = paste(x.name, "CC")))
-  } else {
-    warning("Color 'type' = ", type, " not implemented for 'source_spct'.")
-    color.out <- NA_character_
-    names(color.out) <- paste(x.name, type)
-    color.out
-  }
-}
-
-#' @describeIn color
-#'
-#' @export
-#'
-#' @param idx logical whether to add a column with the names of the elements of
-#'   spct
-#'
-#' @export
-#'
-color.source_mspct <- function(x, ..., idx = !is.null(names(x))) {
-  msdply(mspct = x, color, ..., idx = idx)
-}
-
-
 # normalization -----------------------------------------------------------
 
 #' Normalization of an R object
 #'
-#' Normalization wavelength of an R object, retireved from the object's
+#' Normalization wavelength of an R object, retrieved from the object's
 #' attributes.
 #'
 #' @param x an R object
@@ -500,7 +345,7 @@ normalization.waveband <- function(x) {
 
 #' Is an R object "effective"
 #'
-#' A generic function for quering if a biological spectral weighting function
+#' A generic function for querying if a biological spectral weighting function
 #' (BSWF) has been applied to an object or is included in its definition.
 #'
 #' @param x an R object
@@ -523,7 +368,7 @@ is_effective.default <- function(x) {
 }
 
 #' @describeIn is_effective Is a \code{waveband} object defining a method for
-#'   calcualtaing effective irradiance.
+#'   calculating effective irradiance.
 #'
 #' @export
 #'
@@ -574,7 +419,7 @@ is_effective.summary_source_spct <- function(x) {
 #' Stepsize
 #'
 #' Function that returns the range of step sizes in an object. Range of
-#' differences between succesive sorted values.
+#' differences between successive sorted values.
 #'
 #' @param x an R object
 #' @param ... not used in current version
@@ -634,9 +479,3 @@ stepsize.generic_spct <- function(x, ...) {
 stepsize.generic_mspct <- function(x, ..., idx = !is.null(names(x))) {
   msdply(mspct = x, .fun = stepsize, ..., idx = idx)
 }
-
-
-
-
-
-
